Module coverage

Module coverage 

In-memory coverage and gap analysis over the 64-bit index interval ID domain.

Modules

index_interval
Stable order-preserving mappings from ordered-index values to index interval IDs.

Structs

Coverage
In-memory coverage over a discrete set of index interval IDs.
EntityCoverage
Independent index interval IDs for each ordered entity identity.
EntityIdentity
Ordered composite entity identity.
RoaringTreemap
A compressed bitmap with u64 values. Implemented as a BTreeMap of RoaringBitmaps.

Enums

CoverageCodecError
Errors from the global and entity-aware coverage codecs.
CoverageLayoutError
Errors that can occur during coverage layout operations.
CoverageSidecarError
Errors that can occur during coverage sidecar operations.
EntityIdentityError
Invalid entity identity construction.
EntityValue
Exact scalar value in an entity identity.
SegmentCoverageError
Errors that can occur when reading or computing segment coverage.

Type Aliases

IndexIntervalId
Ordered 64-bit index interval ID.