#[non_exhaustive]pub enum IndexIntervalMappingError {
IndexValue {
source: IndexValueError,
},
ZeroTimeIndexGranularity,
RangeEndUnderflow {
end: IndexValue,
},
IntervalIdOutsideDomain {
kind: &'static str,
index_interval_id: IndexIntervalId,
},
}Expand description
Errors produced while mapping ordered values to index interval IDs.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IndexValue
The value or range does not match the registered index domain.
Fields

source: IndexValueErrorDomain or range validation error.
ZeroTimeIndexGranularity
A directly constructed timestamp index granularity has a zero width.
RangeEndUnderflow
A validated range end could not be adjusted to the final included value.
Fields

end: IndexValueExclusive range end.
IntervalIdOutsideDomain
An index interval ID cannot occur in the configured logical index domain.
Fields

index_interval_id: IndexIntervalIdInternal index interval ID.