pub enum EntityCoverageSerdeError {
LengthOverflow {
field: &'static str,
},
SerializeCoverage {
source: CoverageSerdeError,
},
InvalidMagic,
Truncated,
InvalidLength {
field: &'static str,
},
InvalidString {
source: Utf8Error,
},
UnknownValueType {
tag: u8,
},
InvalidIdentity {
source: EntityIdentityError,
},
DuplicateIdentity {
identity: EntityIdentity,
},
MalformedCoverage {
source: CoverageSerdeError,
},
TrailingBytes,
}Expand description
Errors from the distinct entity-aware coverage encoding.
Variants
LengthOverflow
An in-memory length cannot be represented by the format.
SerializeCoverage
A nested bitmap could not be serialized.
Fields

source: CoverageSerdeErrorThe nested global coverage error.
InvalidMagic
The payload is not entity-aware coverage.
Truncated
A fixed-size field is incomplete.
InvalidLength
A declared count or length is not valid for the remaining payload.
InvalidString
An identity component is not valid UTF-8.
UnknownValueType
An identity component uses an unknown scalar type tag.
InvalidIdentity
An encoded identity is incomplete.
Fields

source: EntityIdentityErrorThe identity validation error.
DuplicateIdentity
The payload contains the same identity more than once.
Fields

identity: EntityIdentityThe repeated identity.
MalformedCoverage
A nested RoaringTreemap payload is malformed.
Fields

source: CoverageSerdeErrorThe nested global coverage error.
TrailingBytes
Bytes remain after the declared entity entries.