pub enum EntityRewriteError {
InvalidInput {
reason: String,
},
InvalidOutput {
reason: String,
},
SegmentInspection {
source: SegmentError,
},
CoverageInspection {
source: SegmentCoverageError,
},
CoverageSidecar {
source: CoverageError,
},
CoverageSerialization {
source: EntityCoverageSerdeError,
},
Storage {
source: StorageError,
},
Parquet {
path: String,
source: ParquetError,
backtrace: Backtrace,
},
Arrow {
path: String,
source: ArrowError,
backtrace: Backtrace,
},
Cleanup {
source: Box<EntityRewriteError>,
cleanup_errors: Vec<String>,
},
}Expand description
Failure while staging a mixed segment rewrite.
Variants
InvalidInput
The committed source or table metadata violates the rewrite contract.
InvalidOutput
A completed staged output violates a rewrite invariant.
SegmentInspection
Segment metadata or schema inspection failed.
Fields

source: SegmentErrorExisting Parquet inspection failure.
CoverageInspection
Exact entity coverage inspection failed.
Fields

source: SegmentCoverageErrorExisting entity coverage inspection failure.
CoverageSidecar
Coverage sidecar access failed.
Fields

source: CoverageErrorExisting coverage sidecar failure.
CoverageSerialization
Entity coverage serialization failed.
Fields

source: EntityCoverageSerdeErrorExisting coverage codec failure.
Storage
Storage access failed.
Fields

source: StorageErrorExisting storage failure.
Parquet
Parquet streaming or writing failed.
Fields

source: ParquetErrorExisting Parquet failure.
Arrow
Filtering a complete record batch failed.
Fields

source: ArrowErrorExisting Arrow failure.
Cleanup
Rewrite failed and one or more private objects could not be removed.