#[non_exhaustive]pub enum IndexSpecError {
EmptyColumn,
EmptyEntityColumn {
position: usize,
},
DuplicateEntityColumn {
column: String,
},
EntityColumnMatchesIndex {
column: String,
},
ZeroTimeIndexGranularity,
}Expand description
Structural errors in an IndexSpec.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyColumn
The registered index column is empty.
EmptyEntityColumn
An entity column is empty.
DuplicateEntityColumn
An entity column is repeated.
EntityColumnMatchesIndex
An entity column is also the ordered index column.
ZeroTimeIndexGranularity
A timestamp index granularity was constructed directly with a zero width.