#[non_exhaustive]pub enum ArrowToLogicalSchemaError {
Unsupported {
column: String,
data_type: DataType,
},
InvalidArrowLogicalSchema {
source: LogicalSchemaValidationError,
},
}Expand description
Errors converting an Arrow schema into the table logical schema model.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
An Arrow type cannot be represented exactly by the logical schema model.
Fields
InvalidArrowLogicalSchema
The converted fields do not form a valid logical schema.
Fields

source: LogicalSchemaValidationErrorLogical schema validation failure.