LogicalSchemaValidationError

Enum LogicalSchemaValidationError 

#[non_exhaustive]
pub enum LogicalSchemaValidationError { DuplicateColumn { column: String, }, FixedBinaryInvalidWidthInSchema { column: String, byte_width: i32, }, FixedBinaryMissingLength { column: String, }, DuplicateFieldName { column_path: String, field: String, }, InvalidMapKeyNullability { column_path: String, }, EmptyStruct { column_path: String, }, ListElementNameEmpty { column_path: String, }, StructFieldNameEmpty { column_path: String, field: String, }, UnsupportedParquetListEncoding { column_path: String, details: String, }, UnsupportedParquetMapEncoding { column_path: String, details: String, }, }
Errors that can occur while constructing or validating a logical schema.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DuplicateColumn

Duplicate column names are not allowed.

Fields

column: String

The duplicate column name.



FixedBinaryInvalidWidthInSchema

FixedBinary columns must include a positive byte width.

Fields

column: String

Column name that failed validation.

byte_width: i32

Declared byte width.



FixedBinaryMissingLength

Parquet FIXED_LEN_BYTE_ARRAY columns must include a type_length.

Fields

column: String

Column name that failed validation.



DuplicateFieldName

Duplicate field names within a struct are not allowed.

Fields

column_path: String

Column path for the struct that contains the duplicate field.

field: String

Duplicate field name.



InvalidMapKeyNullability

Map key fields must be non-nullable in schema validation.

Fields

column_path: String

Column path for the map with an invalid key nullability.



EmptyStruct

Struct fields must be non-empty.

Fields

column_path: String

Column path for the empty struct.



ListElementNameEmpty

List element fields must have a non-empty name.

Fields

column_path: String

Column path for the list with an empty element name.



StructFieldNameEmpty

Struct fields must have a non-empty name.

Fields

column_path: String

Column path for the struct with an empty field name.

field: String

Empty field name.



UnsupportedParquetListEncoding

Parquet LIST encoding does not match the supported layout.

Fields

column_path: String

Column path for the list with unsupported encoding.

details: String

Details describing why the LIST encoding is unsupported.



UnsupportedParquetMapEncoding

Parquet MAP encoding does not match the supported layout.

Fields

column_path: String

Column path for the map with unsupported encoding.

details: String

Details describing why the MAP encoding is unsupported.