#[non_exhaustive]pub enum LogicalToArrowSchemaError {
FixedBinaryInvalidWidth {
column: String,
byte_width: i32,
backtrace: Backtrace,
},
Int96Unsupported {
column: String,
backtrace: Backtrace,
},
OtherTypeUnsupported {
column: String,
name: String,
backtrace: Backtrace,
},
DecimalInvalid {
column: String,
precision: i32,
scale: i32,
details: String,
backtrace: Backtrace,
},
MapKeyMustBeNonNull {
column: String,
backtrace: Backtrace,
},
}Expand description
Errors encountered while converting a logical schema to Arrow.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FixedBinaryInvalidWidth
FixedBinary fields must declare a positive byte width.
Fields
Int96Unsupported
Int96 cannot be represented without legacy timestamp ambiguity.
Fields
OtherTypeUnsupported
A named catch-all logical type cannot be represented in Arrow.
Fields
DecimalInvalid
Decimal precision/scale is out of supported bounds for Arrow conversion.
Fields
MapKeyMustBeNonNull
Map keys must be non-nullable when converting to Arrow.