#[non_exhaustive]pub enum TableProtocolError {
UnsupportedVersion {
expected: u32,
found: u64,
},
UnsupportedReaderFeatures {
features: Vec<String>,
},
UnsupportedWriterFeatures {
features: Vec<String>,
},
ReaderFeaturesRemoved {
features: Vec<String>,
},
WriterFeaturesRemoved {
features: Vec<String>,
},
ProtocolVersionDecreased {
previous: u32,
next: u32,
},
}Expand description
A table protocol requirement or transition is not supported.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedVersion
The table uses a core protocol version this client cannot decode.
Fields
UnsupportedReaderFeatures
The table requires reader features this client does not support.
UnsupportedWriterFeatures
The table requires writer features this client does not support.
ReaderFeaturesRemoved
A metadata update removed previously required reader features.
WriterFeaturesRemoved
A metadata update removed previously required writer features.
ProtocolVersionDecreased
A metadata update decreased the core protocol version.