SchemaCompatibilityError

Enum SchemaCompatibilityError 

#[non_exhaustive]
pub enum SchemaCompatibilityError {
Show 17 variants MissingTableSchema, MissingColumn { column: String, }, MissingIndexColumn { column: String, }, MissingEntityColumn { column: String, }, UnsupportedEntityColumnType { column: String, actual: LogicalDataType, }, EntityIdentityArityMismatch { expected: usize, actual: usize, }, EntityIdentityTypeMismatch { column: String, expected: LogicalDataType, actual: &'static str, }, ExtraColumn { column: String, }, MissingIncomingColumn { column: String, }, ExtraIncomingColumn { column: String, }, DuplicateIncomingColumn { column: String, }, IncomingNullabilityMismatch { column: String, table_nullable: bool, incoming_nullable: bool, }, IncomingTypeMismatch { column: String, table_type: DataType, incoming_type: DataType, }, RegisteredSchemaConversion { source: Box<LogicalToArrowSchemaError>, }, TypeMismatch { column: String, table_type: LogicalDataType, segment_type: LogicalDataType, }, IndexColumnTypeMismatch { column: String, table_type: LogicalDataType, segment_type: LogicalDataType, }, IndexKindMismatch { column: String, expected: &'static str, actual: LogicalDataType, },
}
Errors raised when a segment’s schema is not compatible with the table.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MissingTableSchema

The table does not yet have a canonical logical schema.

Many call sites (like append) may choose to not use this and instead adopt the first segment’s schema, but we keep the error available for operations that require a fixed schema.



MissingColumn

The segment is missing a column that exists in the table schema.

Fields

column: String

The name of the missing column.



MissingIndexColumn

The logical schema does not contain the registered index column.

Fields

column: String

Registered index column name.



MissingEntityColumn

The logical schema does not contain a configured entity column.

Fields

column: String

Configured entity column name.



UnsupportedEntityColumnType

A configured entity column has an unsupported logical type.

Fields

column: String

Configured entity column name.

actual: LogicalDataType

Unsupported logical type.



EntityIdentityArityMismatch

A persisted single-entity identity has the wrong component count.

Fields

expected: usize

Configured entity column count.

actual: usize

Persisted identity component count.



EntityIdentityTypeMismatch

A persisted entity component has the wrong scalar type.

Fields

column: String

Configured entity column name.

expected: LogicalDataType

Logical type required by the table schema.

actual: &'static str

Persisted scalar type.



ExtraColumn

The segment has an extra column that does not exist in the table schema.

Fields

column: String

The name of the extra column.



MissingIncomingColumn

An incoming Arrow schema is missing a registered table column.

Fields

column: String

The missing registered column name.



ExtraIncomingColumn

An incoming Arrow schema contains an unregistered column.

Fields

column: String

The extra incoming column name.



DuplicateIncomingColumn

An incoming Arrow schema repeats one column name.

Fields

column: String

The duplicated incoming column name.



IncomingNullabilityMismatch

An incoming Arrow field changes the registered nullability.

Fields

column: String

The column with mismatched nullability.

table_nullable: bool

Registered table nullability.

incoming_nullable: bool

Incoming Arrow nullability.



IncomingTypeMismatch

An incoming Arrow type is neither exact nor an allowlisted widening.

Fields

column: String

The column with the incompatible Arrow type.

table_type: DataType

Arrow type required by the registered table schema.

incoming_type: DataType

Arrow type declared by the incoming source.



RegisteredSchemaConversion

The registered logical schema cannot be represented as Arrow.

Fields

source: Box<LogicalToArrowSchemaError>

The logical-to-Arrow conversion failure.



TypeMismatch

Column exists in both schemas, but the logical type / nullability differ.

Fields

column: String

The name of the column with mismatched type.

table_type: LogicalDataType

The type in the table schema.

segment_type: LogicalDataType

The type in the segment schema.



IndexColumnTypeMismatch

Specialized version of TypeMismatch for the ordered index column.

Fields

column: String

The name of the ordered index column.

table_type: LogicalDataType

The type in the table schema.

segment_type: LogicalDataType

The type in the segment schema.



IndexKindMismatch

The registered index kind disagrees with the logical schema.

Fields

column: String

Registered index column name.

expected: &'static str

Expected ordered domain.

actual: LogicalDataType

Logical type found in the schema.