#[non_exhaustive]pub enum StorageError {
InvalidRelativePath {
path: String,
reason: String,
backtrace: Box<Backtrace>,
},
NotFound {
path: String,
source: StorageBackendError,
backtrace: Backtrace,
},
AlreadyExists {
path: String,
source: StorageBackendError,
backtrace: Backtrace,
},
OtherIo {
path: String,
source: StorageBackendError,
backtrace: Backtrace,
},
CleanupFailed {
path: String,
operation_error: Box<StorageError>,
cleanup_error: Box<StorageError>,
},
}Expand description
Errors that can occur during storage operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidRelativePath
A table-relative storage path is invalid or non-canonical.
Fields
NotFound
The specified path was not found.
Fields

source: StorageBackendErrorUnderlying storage backend error that caused the failure.
AlreadyExists
The specified path already exists when creation was requested with create-new semantics.
Fields

source: StorageBackendErrorUnderlying storage backend error that indicates the existing resource.
OtherIo
An I/O error occurred in the storage backend.
Fields

source: StorageBackendErrorUnderlying storage backend error with platform-specific details.
CleanupFailed
A newly-created object could not be removed after its write failed.
Fields

operation_error: Box<StorageError>Original write or sync failure.

cleanup_error: Box<StorageError>Failure encountered while removing the newly-created object.