pub struct LogicalSchema { /* private fields */ }Expand description
Logical schema metadata describing the ordered collection of logical columns.
Implementations
Sourceimpl LogicalSchema
impl LogicalSchema
Sourcepub fn to_arrow_schema(&self) -> Result<Schema, SchemaConvertError>
pub fn to_arrow_schema(&self) -> Result<Schema, SchemaConvertError>
Convert this logical schema to an owned Arrow Schema.
Fails if any column uses a logical type that cannot be represented in
Arrow (see SchemaConvertError).
Sourcepub fn to_arrow_schema_ref(&self) -> Result<Arc<Schema>, SchemaConvertError>
pub fn to_arrow_schema_ref(&self) -> Result<Arc<Schema>, SchemaConvertError>
Convert this logical schema to a shared Arrow SchemaRef.
This is a convenience wrapper around Self::to_arrow_schema.
Sourceimpl LogicalSchema
impl LogicalSchema
Sourcepub fn new(
columns: Vec<LogicalField>,
) -> Result<LogicalSchema, LogicalSchemaError>
pub fn new( columns: Vec<LogicalField>, ) -> Result<LogicalSchema, LogicalSchemaError>
Construct a validated logical schema (rejects duplicate column names).
Sourcepub fn columns(&self) -> &[LogicalField]
pub fn columns(&self) -> &[LogicalField]
Borrow the logical columns.