Module table

Module table 

High-level time-series table abstraction.

This module is the canonical home for the user-facing TimeSeriesTable API.

Modules

append
Append pipeline for TimeSeriesTable.

Structs

AppendReport
Result of one successfully committed append operation.
OptimizeReport
Result of one entity-layout optimization operation.
TimeSeriesTable
High-level time-series table handle.
VacuumArtifact
Vacuum classification for one file below a scanned directory.
VacuumReport
Structured result of one vacuum invocation.

Enums

AppendError
Errors owned by an append operation.
CoverageQueryError
Errors from table coverage queries and read-only coverage recovery.
CreateTableError
Errors owned by a table creation operation.
EntityRewriteError
Failure while staging a mixed segment rewrite.
OpenTableError
Errors owned by a table open operation.
OptimizeError
Errors owned by an entity-layout optimization operation.
ScanError
Errors from planning or lazily executing a table scan.
TableError
Errors from high-level time-series table operations.
TableStateAccessError
Errors owned by table state reads and refreshes.
VacuumArtifactDisposition
The action vacuum took or would take for one considered file.
VacuumArtifactReason
Why vacuum retained or selected one file.
VacuumError
Errors owned by a vacuum operation.
VacuumMode
Whether vacuum reports candidates or removes them.

Type Aliases

TimeSeriesScan
Stream of Arrow RecordBatch values from a time-series scan.