CoverageQueryError

Enum CoverageQueryError 

#[non_exhaustive]
pub enum CoverageQueryError {
Show 13 variants InvalidRange { source: IndexValueError, backtrace: Box<Backtrace>, }, IndexIntervalMapping { source: IndexIntervalMappingError, backtrace: Box<Backtrace>, }, InvalidEntityIdentity { source: EntityIdentityError, backtrace: Box<Backtrace>, }, SchemaCompatibility { source: Box<SchemaCompatibilityError>, }, EntityIdentityRequired { entity_columns: Vec<String>, backtrace: Box<Backtrace>, }, EntityIdentityNotConfigured { backtrace: Box<Backtrace>, }, MissingEntityIdentityColumn { column: String, backtrace: Box<Backtrace>, }, DuplicateEntityIdentityColumn { column: String, backtrace: Box<Backtrace>, }, UnexpectedEntityIdentityColumn { column: String, backtrace: Box<Backtrace>, }, CoverageSnapshotRead { coverage_path: String, source: Box<CoverageSidecarError>, }, ExistingSegmentMissingCoverageMetadata { segment_path: String, backtrace: Box<Backtrace>, }, SegmentCoverageSidecarRead { segment_path: String, coverage_path: String, source: Box<CoverageSidecarError>, }, MissingTableCoveragePointer { backtrace: Box<Backtrace>, },
}
Errors from table coverage queries and read-only coverage recovery.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidRange

The requested half-open ordered-index range is invalid.

Fields

source: IndexValueError

Complete range validation error.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



IndexIntervalMapping

An ordered value could not be mapped to its index interval ID.

Fields

source: IndexIntervalMappingError

Complete interval mapping error.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



InvalidEntityIdentity

Constructing a canonical entity identity failed.

Fields

source: EntityIdentityError

Complete entity identity construction error.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



SchemaCompatibility

The query identity is incompatible with the table schema.

Fields

source: Box<SchemaCompatibilityError>

Complete schema compatibility error.



EntityIdentityRequired

An identity-free query was used on an entity-aware table.

Fields

entity_columns: Vec<String>

Entity columns that require values from the caller.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



EntityIdentityNotConfigured

An entity-aware query was used on a table with global coverage.

Fields

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



MissingEntityIdentityColumn

A required entity column has no caller-provided value.

Fields

column: String

Configured entity column missing from the caller input.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



DuplicateEntityIdentityColumn

Caller input repeats one entity column.

Fields

column: String

Repeated entity column name.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



UnexpectedEntityIdentityColumn

Caller input contains a column outside the entity identity.

Fields

column: String

Unknown entity column name.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



CoverageSnapshotRead

Reading a table coverage snapshot sidecar failed.

Fields

coverage_path: String

Table-relative sidecar path.

source: Box<CoverageSidecarError>

Complete sidecar error, including storage or codec detail.



ExistingSegmentMissingCoverageMetadata

An existing segment has no coverage sidecar path.

Fields

segment_path: String

Canonical segment path missing a coverage path.

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.



SegmentCoverageSidecarRead

Reading a segment sidecar failed during read-only recovery.

Fields

segment_path: String

Canonical segment path.

coverage_path: String

Table-relative sidecar path.

source: Box<CoverageSidecarError>

Complete sidecar error, including storage or codec detail.



MissingTableCoveragePointer

Table state has segments but no coverage snapshot pointer.

Fields

backtrace: Box<Backtrace>

Backtrace captured at the coverage query boundary.