EntityRewriteError

Enum EntityRewriteError 

#[non_exhaustive]
pub enum EntityRewriteError {
Show 15 variants InvalidInput { reason: String, backtrace: Backtrace, }, InvalidOutput { reason: String, backtrace: Backtrace, }, InvalidPath { description: &'static str, path: String, source: Box<StorageError>, }, IndexSpecValidation { source: IndexSpecError, backtrace: Backtrace, }, TableSchemaValidation { source: Box<SchemaCompatibilityError>, }, SegmentSchemaValidation { path: String, source: Box<SchemaCompatibilityError>, }, SegmentMetadataValidation { source: Box<SegmentMetaError>, }, SegmentInspection { source: SegmentError, }, CoverageInspection { source: SegmentCoverageError, }, CoverageSidecar { source: CoverageSidecarError, }, CoverageSerialization { source: CoverageCodecError, }, Storage { source: StorageError, }, Parquet { path: String, source: ParquetError, backtrace: Backtrace, }, Arrow { path: String, source: ArrowError, backtrace: Backtrace, }, Cleanup { source: Box<EntityRewriteError>, cleanup_errors: Vec<StorageError>, },
}
Failure while staging a mixed segment rewrite.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidInput

The committed source or table metadata violates the rewrite contract.

Fields

reason: String

Inconsistent input detail.

backtrace: Backtrace

Backtrace captured at the invalid rewrite boundary.



InvalidOutput

A completed staged output violates a rewrite invariant.

Fields

reason: String

Failed output invariant.

backtrace: Backtrace

Backtrace captured at the failed rewrite invariant.



InvalidPath

A source or sidecar path failed table-relative storage validation.

Fields

description: &'static str

Role of the rejected path in the rewrite.

path: String

Rejected path.

source: Box<StorageError>

Structured storage path validation failure.



IndexSpecValidation

The rewrite received an invalid ordered-index specification.

Fields

source: IndexSpecError

Complete ordered-index validation failure.

backtrace: Backtrace

Backtrace captured at the rewrite boundary.



TableSchemaValidation

The table schema is incompatible with its ordered-index specification.

Fields

source: Box<SchemaCompatibilityError>

Complete schema compatibility failure.



SegmentSchemaValidation

A source or replacement segment schema is incompatible with the table schema.

Fields

path: String

Source or staged replacement path.

source: Box<SchemaCompatibilityError>

Complete schema compatibility failure.



SegmentMetadataValidation

Persisted source segment metadata violates the registered ordered-index domain.

Fields

source: Box<SegmentMetaError>

Complete segment metadata validation failure.



SegmentInspection

Segment metadata or schema inspection failed.

Fields

source: SegmentError

Existing Parquet inspection failure.



CoverageInspection

Exact entity coverage inspection failed.

Fields

source: SegmentCoverageError

Existing entity coverage inspection failure.



CoverageSidecar

Coverage sidecar access failed.

Fields

source: CoverageSidecarError

Existing coverage sidecar failure.



CoverageSerialization

Entity coverage serialization failed.

Fields

source: CoverageCodecError

Existing coverage codec failure.



Storage

Storage access failed.

Fields

source: StorageError

Existing storage failure.



Parquet

Parquet streaming or writing failed.

Fields

path: String

Table-relative source or output path.

source: ParquetError

Existing Parquet failure.

backtrace: Backtrace

Diagnostic backtrace.



Arrow

Filtering a complete record batch failed.

Fields

path: String

Table-relative source path.

source: ArrowError

Existing Arrow failure.

backtrace: Backtrace

Diagnostic backtrace.



Cleanup

Rewrite failed and one or more private objects could not be removed.

Fields

source: Box<EntityRewriteError>

Primary rewrite failure.

cleanup_errors: Vec<StorageError>

Typed cleanup failure for every private object that could not be removed.