OptimizeError

Enum OptimizeError 

#[non_exhaustive]
pub enum OptimizeError { Protocol { source: TableProtocolError, backtrace: Backtrace, }, NotApplicable { table_root: String, }, MixedSegmentRewrite { source: Box<EntityRewriteError>, }, InvalidSegmentBounds { source: IndexValueError, backtrace: Backtrace, }, SchemaValidation { source: Box<SchemaCompatibilityError>, }, CoverageSidecar { source: Box<CoverageSidecarError>, }, InvalidStagedPath { description: &'static str, path: String, source: Box<StorageError>, }, InvalidStagedPlan { reason: String, backtrace: Backtrace, }, CountOverflow { field: &'static str, backtrace: Backtrace, }, Commit { source: CommitError, }, Rollback { source: Box<OptimizeError>, cleanup_errors: Vec<StorageError>, }, }
Errors owned by an entity-layout optimization operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Protocol

The table protocol does not permit this client to optimize.

Fields

source: TableProtocolError

Complete table protocol failure.

backtrace: Backtrace

Backtrace captured at the optimization boundary.



NotApplicable

Entity-layout optimization requires at least one entity column.

Fields

table_root: String

User-facing table root.



MixedSegmentRewrite

Staging replacements for one mixed segment failed.

Fields

source: Box<EntityRewriteError>

Complete mixed-segment rewrite failure.



InvalidSegmentBounds

Live segment bounds cannot be ordered in one native index domain.

Fields

source: IndexValueError

Complete bounds validation failure.

backtrace: Backtrace

Backtrace captured because index value validation does not own one.



SchemaValidation

Optimization cannot use the table’s canonical schema.

Fields

source: Box<SchemaCompatibilityError>

Complete schema compatibility failure.



CoverageSidecar

A coverage sidecar required to validate a staged plan could not be read.

Fields

source: Box<CoverageSidecarError>

Complete coverage sidecar failure.



InvalidStagedPath

A staged replacement path failed table-relative storage validation.

Fields

description: &'static str

Role of the rejected path in the staged replacement.

path: String

Rejected table-relative path.

source: Box<StorageError>

Complete storage path validation failure.



InvalidStagedPlan

A staged optimization plan violated an atomic publication invariant.

Fields

reason: String

Failed plan invariant.

backtrace: Backtrace

Backtrace captured at the failed internal invariant.



CountOverflow

An optimization count could not be represented without wrapping.

Fields

field: &'static str

Report or version field that overflowed.

backtrace: Backtrace

Backtrace captured at the failed internal arithmetic boundary.



Commit

Publishing the optimization transaction failed.

Fields

source: CommitError

Complete transaction-log failure.



Rollback

Optimization failed and one or more owned staged objects could not be removed.

Fields

source: Box<OptimizeError>

Original optimization failure that triggered rollback.

cleanup_errors: Vec<StorageError>

Typed cleanup failure for every staged object that could not be removed.