#[non_exhaustive]pub enum ScanError {
InvalidRange {
source: IndexValueError,
backtrace: Box<Backtrace>,
},
InvalidSegmentBounds {
source: IndexValueError,
backtrace: Box<Backtrace>,
},
Storage {
path: String,
source: Box<StorageError>,
},
Parquet {
path: String,
operation: &'static str,
source: Box<ParquetError>,
backtrace: Box<Backtrace>,
},
Arrow {
path: String,
column: String,
operation: &'static str,
source: Box<ArrowError>,
backtrace: Box<Backtrace>,
},
MissingIndexColumn {
path: String,
column: String,
backtrace: Box<Backtrace>,
},
IndexColumnTypeMismatch {
path: String,
column: String,
expected: &'static str,
datatype: Box<DataType>,
backtrace: Box<Backtrace>,
},
TimeConversionOverflow {
path: String,
column: String,
timestamp: DateTime<Utc>,
backtrace: Box<Backtrace>,
},
}Expand description
Errors from planning or lazily executing a table scan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidRange
The requested half-open ordered-index range is invalid.
Fields

source: IndexValueErrorComplete range validation error.
InvalidSegmentBounds
Persisted segment bounds cannot be ordered in the table’s index domain.
Fields

source: IndexValueErrorComplete segment bounds error.
Storage
Opening a segment from storage failed during lazy scan execution.
Parquet
Reading Parquet metadata or batches failed.
Fields

source: Box<ParquetError>Complete Parquet error.
Arrow
An Arrow compute operation failed while filtering a batch.
Fields

source: Box<ArrowError>Complete Arrow error.
MissingIndexColumn
A segment is missing the configured ordered-index column.
Fields
IndexColumnTypeMismatch
A segment’s ordered-index Arrow type disagrees with the table index.
Fields
TimeConversionOverflow
Converting a timestamp bound to the segment’s unit would overflow i64.