#[non_exhaustive]pub enum VacuumArtifactReason {
ReferencedByCommit {
version: u64,
},
WithinRetention,
ChangedSincePlanning,
UnrecognizedArtifact,
Unreferenced,
InvalidOrUnreadableParquet,
}Expand description
Why vacuum retained or selected one file.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReferencedByCommit
A retained commit references this path.
WithinRetention
The file modification time is at or after the required cutoff.
ChangedSincePlanning
The file’s size or modification time differed from the planned metadata.
UnrecognizedArtifact
The file is below a scanned directory but does not have a reserved managed shape.
Unreferenced
The file is expired and no retained commit references it.
InvalidOrUnreadableParquet
The expired, unreferenced Parquet file has no readable valid footer.
Implementations