#[non_exhaustive]pub enum VacuumError {
FutureCutoff {
older_than: DateTime<Utc>,
},
Protocol {
source: TableProtocolError,
backtrace: Backtrace,
},
NotTimeSeries {
kind: TableKind,
},
Commit {
source: CommitError,
},
Storage {
source: StorageError,
},
Delete {
path: String,
source: StorageError,
partial_report: Box<VacuumReport>,
},
}Expand description
Errors owned by a vacuum operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FutureCutoff
The retention cutoff is later than the current time.
Protocol
The latest table protocol does not permit this client to vacuum.
Fields

source: TableProtocolErrorComplete table protocol failure.
NotTimeSeries
The latest metadata no longer describes a time-series table.
Commit
Reading or validating retained transaction-log history failed.
Fields

source: CommitErrorComplete transaction-log failure.
Storage
Listing or inspecting table-managed storage failed.
Fields

source: StorageErrorComplete storage failure.
Delete
Removing one selected file failed.
Fields

source: StorageErrorComplete storage failure.

partial_report: Box<VacuumReport>Report state after every deletion completed before this failure.