#[non_exhaustive]pub enum LogicalSchemaValidationError {
DuplicateColumn {
column: String,
},
FixedBinaryInvalidWidthInSchema {
column: String,
byte_width: i32,
},
FixedBinaryMissingLength {
column: String,
},
DuplicateFieldName {
column_path: String,
field: String,
},
InvalidMapKeyNullability {
column_path: String,
},
EmptyStruct {
column_path: String,
},
ListElementNameEmpty {
column_path: String,
},
StructFieldNameEmpty {
column_path: String,
field: String,
},
UnsupportedParquetListEncoding {
column_path: String,
details: String,
},
UnsupportedParquetMapEncoding {
column_path: String,
details: String,
},
}Expand description
Errors that can occur while constructing or validating a logical schema.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DuplicateColumn
Duplicate column names are not allowed.
FixedBinaryInvalidWidthInSchema
FixedBinary columns must include a positive byte width.
FixedBinaryMissingLength
Parquet FIXED_LEN_BYTE_ARRAY columns must include a type_length.
DuplicateFieldName
Duplicate field names within a struct are not allowed.
Fields
InvalidMapKeyNullability
Map key fields must be non-nullable in schema validation.
EmptyStruct
Struct fields must be non-empty.
ListElementNameEmpty
List element fields must have a non-empty name.
StructFieldNameEmpty
Struct fields must have a non-empty name.
Fields
UnsupportedParquetListEncoding
Parquet LIST encoding does not match the supported layout.
Fields
UnsupportedParquetMapEncoding
Parquet MAP encoding does not match the supported layout.