SchemaCompatibilityError

Enum SchemaCompatibilityError 

pub enum SchemaCompatibilityError {
    MissingTableSchema,
    MissingColumn {
        column: String,
    },
    MissingIndexColumn {
        column: String,
    },
    MissingEntityColumn {
        column: String,
    },
    UnsupportedEntityColumnType {
        column: String,
        actual: LogicalDataType,
    },
    EntityIdentityArityMismatch {
        expected: usize,
        actual: usize,
    },
    EntityIdentityTypeMismatch {
        column: String,
        expected: LogicalDataType,
        actual: &'static str,
    },
    ExtraColumn {
        column: String,
    },
    TypeMismatch {
        column: String,
        table_type: LogicalDataType,
        segment_type: LogicalDataType,
    },
    IndexColumnTypeMismatch {
        column: String,
        table_type: LogicalDataType,
        segment_type: LogicalDataType,
    },
    IndexKindMismatch {
        column: String,
        expected: &'static str,
        actual: LogicalDataType,
    },
    LogicalSchema {
        source: LogicalSchemaError,
    },
}
Errors raised when a segment’s schema is not compatible with the table.

Variants



MissingTableSchema

The table does not yet have a canonical logical schema.

Many call sites (like append) may choose to not use this and instead adopt the first segment’s schema, but we keep the error available for operations that require a fixed schema.



MissingColumn

The segment is missing a column that exists in the table schema.

Fields

column: String

The name of the missing column.



MissingIndexColumn

The logical schema does not contain the registered index column.

Fields

column: String

Registered index column name.



MissingEntityColumn

The logical schema does not contain a configured entity column.

Fields

column: String

Configured entity column name.



UnsupportedEntityColumnType

A configured entity column has an unsupported logical type.

Fields

column: String

Configured entity column name.

actual: LogicalDataType

Unsupported logical type.



EntityIdentityArityMismatch

A persisted single-entity identity has the wrong component count.

Fields

expected: usize

Configured entity column count.

actual: usize

Persisted identity component count.



EntityIdentityTypeMismatch

A persisted entity component has the wrong scalar type.

Fields

column: String

Configured entity column name.

expected: LogicalDataType

Logical type required by the table schema.

actual: &'static str

Persisted scalar type.



ExtraColumn

The segment has an extra column that does not exist in the table schema.

Fields

column: String

The name of the extra column.



TypeMismatch

Column exists in both schemas, but the logical type / nullability differ.

Fields

column: String

The name of the column with mismatched type.

table_type: LogicalDataType

The type in the table schema.

segment_type: LogicalDataType

The type in the segment schema.



IndexColumnTypeMismatch

Specialized version of TypeMismatch for the ordered index column.

Fields

column: String

The name of the ordered index column.

table_type: LogicalDataType

The type in the table schema.

segment_type: LogicalDataType

The type in the segment schema.



IndexKindMismatch

The registered index kind disagrees with the logical schema.

Fields

column: String

Registered index column name.

expected: &'static str

Expected ordered domain.

actual: LogicalDataType

Logical type found in the schema.



LogicalSchema

Logical schema construction or validation failed.

Fields

source: LogicalSchemaError

The underlying logical schema error.