SegmentMetaError

Enum SegmentMetaError 

pub enum SegmentMetaError {
    InvalidIndexBounds {
        path: String,
        source: IndexValueError,
    },
    TooShort {
        path: String,
    },
    ParquetRead {
        path: String,
        source: ParquetError,
        backtrace: Backtrace,
    },
    OrderedIndexColumn {
        source: ParquetIndexColumnError,
    },
    ParquetStatsShape {
        path: String,
        column: String,
        detail: String,
    },
    NoObservedIndexValue {
        path: String,
        column: String,
        expected_domain: &'static str,
    },
    LogicalSchemaInvalid {
        path: String,
        source: LogicalSchemaError,
    },
}
Errors that can occur while validating or decoding segment metadata.

This enum intentionally contains no storage backend errors. IO-related errors should be wrapped at the IO boundary (for example, in transaction_log::segments::SegmentError).

Variants



InvalidIndexBounds

Persisted segment bounds violate the table’s ordered-index domain.

Fields

path: String

Segment path containing invalid bounds.

source: IndexValueError

Domain or ordering failure.



TooShort

The file is too short to be a valid Parquet file.

Fields

path: String

The path to the file that was too short.



ParquetRead

Parquet reader / metadata failure.

Fields

path: String

The path to the file that caused the Parquet read failure.

source: ParquetError

Underlying parquet error that caused this failure.

backtrace: Backtrace

Diagnostic backtrace for this error.



OrderedIndexColumn

The registered ordered-index column is missing or incompatible.

Fields

source: ParquetIndexColumnError

Exact registered and observed Parquet column details.



ParquetStatsShape

Statistics exist but are not well-shaped (wrong length / unexpected type).

Fields

path: String

The path to the file with malformed Parquet statistics.

column: String

The column whose statistics are malformed.

detail: String

Details about how the statistics are malformed.



NoObservedIndexValue

The file contains no non-null value for the registered ordered index.

Fields

path: String

Path to the segment file.

column: String

Registered ordered-index column.

expected_domain: &'static str

Registered ordered-index domain.



LogicalSchemaInvalid

Failed to derive a valid LogicalSchema from the Parquet file.

Fields

path: String

The path to the file without a valid LogicalSchema.

source: LogicalSchemaError

Underlying logical schema error that triggered this failure.