TsTableProvider

Struct TsTableProvider 

pub struct TsTableProvider { /* private fields */ }
DataFusion table provider (enabled by default). DataFusion table provider for a timeseries table schema.

The schema is captured when the provider is constructed. If the table schema evolves, re-register a new provider to pick up the updated schema.

Implementations

Source

impl TsTableProvider

pub fn try_new( table: Arc<TimeSeriesTable>, ) -> Result<TsTableProvider, DataFusionError>

Creates a new provider backed by the given TimeSeriesTable.