High-level time-series table abstraction.
This module is the canonical home for the user-facing TimeSeriesTable
API.
Modules
- append
- Append pipeline for
TimeSeriesTable.
Structs
- Append
Report - Result of one successfully committed append operation.
- Optimize
Report - Result of one entity-layout optimization operation.
- Time
Series Table - High-level time-series table handle.
- Vacuum
Artifact - Vacuum classification for one file below a scanned directory.
- Vacuum
Report - Structured result of one vacuum invocation.
Enums
- Append
Error - Errors owned by an append operation.
- Coverage
Query Error - Errors from table coverage queries and read-only coverage recovery.
- Create
Table Error - Errors owned by a table creation operation.
- Entity
Rewrite Error - Failure while staging a mixed segment rewrite.
- Open
Table Error - Errors owned by a table open operation.
- Optimize
Error - Errors owned by an entity-layout optimization operation.
- Scan
Error - Errors from planning or lazily executing a table scan.
- Table
Error - Errors from high-level time-series table operations.
- Table
State Access Error - Errors owned by table state reads and refreshes.
- Vacuum
Artifact Disposition - The action vacuum took or would take for one considered file.
- Vacuum
Artifact Reason - Why vacuum retained or selected one file.
- Vacuum
Error - Errors owned by a vacuum operation.
- Vacuum
Mode - Whether vacuum reports candidates or removes them.
Type Aliases
- Time
Series Scan - Stream of Arrow RecordBatch values from a time-series scan.