High-level time-series table abstraction.
This module is the canonical home for the user-facing TimeSeriesTable
API.
Modules
- append
- Append pipeline for
TimeSeriesTable.
Structs
- Optimize
Report - Result of one entity-layout optimization operation.
- Time
Series Table - High-level time-series table handle.
Enums
- Append
Error - Errors owned by an append operation.
- Coverage
Query Error - Errors from table coverage queries and read-only coverage recovery.
- Create
Table Error - Errors owned by a table creation operation.
- Entity
Rewrite Error - Failure while staging a mixed segment rewrite.
- Open
Table Error - Errors owned by a table open operation.
- Optimize
Error - Errors owned by an entity-layout optimization operation.
- Scan
Error - Errors from planning or lazily executing a table scan.
- Table
Error - Errors from high-level time-series table operations.
- Table
State Access Error - Errors owned by table state reads and refreshes.
Type Aliases
- Time
Series Scan - Stream of Arrow RecordBatch values from a time-series scan.