#[non_exhaustive]pub enum AppendError {
Show 23 variants
Protocol {
source: TableProtocolError,
backtrace: Backtrace,
},
ArrowInput {
source: ArrowError,
backtrace: Backtrace,
},
ArrowToLogicalSchema {
source: ArrowToLogicalSchemaError,
backtrace: Backtrace,
},
EmptyInput,
InvalidMaxRowsPerRowGroup {
max_rows_per_row_group: usize,
},
InvalidMaxBytesPerRowGroup {
max_bytes_per_row_group: usize,
},
SchemaValidation {
source: Box<SchemaCompatibilityError>,
},
GeneratedSegmentSchemaCompatibility {
segment_path: String,
source: Box<SchemaCompatibilityError>,
},
MissingCanonicalTableSchema {
version: u64,
},
SegmentMetadata {
source: Box<SegmentError>,
},
ParquetWrite {
source: ParquetError,
backtrace: Backtrace,
},
GeneratedSegmentCoverage {
source: Box<SegmentCoverageError>,
},
IndexIntervalMapping {
source: IndexIntervalMappingError,
backtrace: Backtrace,
},
CoverageSidecar {
source: Box<CoverageSidecarError>,
},
PersistedIndexIntervalOverlap {
segment_path: String,
overlap_count: u128,
example_identity: Option<EntityIdentity>,
example_index_interval_id: IndexIntervalId,
example_index_interval: Box<IndexInterval>,
},
EmptySegmentEntityCoverage {
segment_path: String,
},
EntityWithoutIndexCoverage {
segment_path: String,
identity: EntityIdentity,
},
ExistingSegmentMissingCoverageMetadata {
segment_path: String,
},
ExistingSegmentCoverageSidecarRead {
segment_path: String,
coverage_path: String,
source: Box<CoverageSidecarError>,
},
Storage {
source: StorageError,
},
Commit {
source: CommitError,
},
CommitAmbiguous {
segment_path: String,
source: Box<CommitError>,
},
Rollback {
source: Box<AppendError>,
cleanup_errors: Vec<StorageError>,
},
}Expand description
Errors owned by an append operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Protocol
The table protocol does not permit this client to append.
Fields
source: TableProtocolErrorComplete table protocol failure.
ArrowInput
An Arrow input reader or batch normalization failed.
Fields
source: ArrowErrorArrow error returned while reading or normalizing a batch.
ArrowToLogicalSchema
An Arrow schema could not be represented by the table logical schema.
Fields
source: ArrowToLogicalSchemaErrorArrow-to-logical schema conversion failure.
EmptyInput
An append input contained no rows.
InvalidMaxRowsPerRowGroup
A configured Parquet row group cannot contain zero rows.
InvalidMaxBytesPerRowGroup
A configured Parquet row group cannot contain zero estimated bytes.
SchemaValidation
Validating the incoming and registered table schemas failed.
Fields
source: Box<SchemaCompatibilityError>Complete schema compatibility failure.
GeneratedSegmentSchemaCompatibility
A generated segment is incompatible with the table schema.
Fields
source: Box<SchemaCompatibilityError>Complete schema compatibility failure.
MissingCanonicalTableSchema
Table state lacks the canonical schema required by append.
SegmentMetadata
Reading metadata from the generated segment failed.
Fields
source: Box<SegmentError>Complete segment metadata failure.
ParquetWrite
Streaming the append input into Parquet failed.
Fields
source: ParquetErrorParquet writer failure.
GeneratedSegmentCoverage
Deriving ordered-index coverage from the generated segment failed.
Fields
source: Box<SegmentCoverageError>Complete segment coverage derivation failure.
IndexIntervalMapping
An ordered-index interval could not be reconstructed for a diagnostic.
Fields
source: IndexIntervalMappingErrorComplete interval mapping failure.
CoverageSidecar
A coverage sidecar could not be prepared or written.
Fields
source: Box<CoverageSidecarError>Complete coverage sidecar failure.
PersistedIndexIntervalOverlap
The generated segment overlaps coverage already persisted by the table.
Fields
example_identity: Option<EntityIdentity>First overlapping identity, or None for a table-wide index.
example_index_interval_id: IndexIntervalIdInternal ID of the example interval.
example_index_interval: Box<IndexInterval>Logical ordered-index interval represented by the example ID.
EmptySegmentEntityCoverage
An entity-aware generated segment produced no entity coverage.
EntityWithoutIndexCoverage
One entity has rows but no usable ordered-index coverage.
Fields
identity: EntityIdentityComplete identity whose rows all have null ordered-index values.
ExistingSegmentMissingCoverageMetadata
An existing segment lacks coverage metadata required by append.
ExistingSegmentCoverageSidecarRead
Reading one existing segment’s coverage sidecar during recovery failed.
Fields
source: Box<CoverageSidecarError>Complete coverage sidecar failure.
Storage
Direct storage access for an append artifact failed.
Fields
source: StorageErrorComplete storage failure.
Commit
Publishing the append transaction failed with a definite outcome.
Fields
source: CommitErrorComplete transaction-log failure.
CommitAmbiguous
The append transaction may have committed, so its artifacts were preserved.
Fields
source: Box<CommitError>Ambiguous transaction-log failure.
Rollback
Append failed and one or more attempt-owned artifacts could not be removed.
Fields
source: Box<AppendError>Original append failure that triggered rollback.
cleanup_errors: Vec<StorageError>Typed cleanup failure for every artifact that could not be removed.