#[non_exhaustive]pub enum EntityRewriteError {
Show 15 variants
InvalidInput {
reason: String,
backtrace: Backtrace,
},
InvalidOutput {
reason: String,
backtrace: Backtrace,
},
InvalidPath {
description: &'static str,
path: String,
source: Box<StorageError>,
},
IndexSpecValidation {
source: IndexSpecError,
backtrace: Backtrace,
},
TableSchemaValidation {
source: Box<SchemaCompatibilityError>,
},
SegmentSchemaValidation {
path: String,
source: Box<SchemaCompatibilityError>,
},
SegmentMetadataValidation {
source: Box<SegmentMetaError>,
},
SegmentInspection {
source: SegmentError,
},
CoverageInspection {
source: SegmentCoverageError,
},
CoverageSidecar {
source: CoverageSidecarError,
},
CoverageSerialization {
source: CoverageCodecError,
},
Storage {
source: StorageError,
},
Parquet {
path: String,
source: ParquetError,
backtrace: Backtrace,
},
Arrow {
path: String,
source: ArrowError,
backtrace: Backtrace,
},
Cleanup {
source: Box<EntityRewriteError>,
cleanup_errors: Vec<StorageError>,
},
}Expand description
Failure while staging a mixed segment rewrite.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidInput
The committed source or table metadata violates the rewrite contract.
Fields
InvalidOutput
A completed staged output violates a rewrite invariant.
Fields
InvalidPath
A source or sidecar path failed table-relative storage validation.
Fields
source: Box<StorageError>Structured storage path validation failure.
IndexSpecValidation
The rewrite received an invalid ordered-index specification.
Fields
source: IndexSpecErrorComplete ordered-index validation failure.
TableSchemaValidation
The table schema is incompatible with its ordered-index specification.
Fields
source: Box<SchemaCompatibilityError>Complete schema compatibility failure.
SegmentSchemaValidation
A source or replacement segment schema is incompatible with the table schema.
Fields
source: Box<SchemaCompatibilityError>Complete schema compatibility failure.
SegmentMetadataValidation
Persisted source segment metadata violates the registered ordered-index domain.
Fields
source: Box<SegmentMetaError>Complete segment metadata validation failure.
SegmentInspection
Segment metadata or schema inspection failed.
Fields
source: SegmentErrorExisting Parquet inspection failure.
CoverageInspection
Exact entity coverage inspection failed.
Fields
source: SegmentCoverageErrorExisting entity coverage inspection failure.
CoverageSidecar
Coverage sidecar access failed.
Fields
source: CoverageSidecarErrorExisting coverage sidecar failure.
CoverageSerialization
Entity coverage serialization failed.
Fields
source: CoverageCodecErrorExisting coverage codec failure.
Storage
Storage access failed.
Fields
source: StorageErrorExisting storage failure.
Parquet
Parquet streaming or writing failed.
Fields
source: ParquetErrorExisting Parquet failure.
Arrow
Filtering a complete record batch failed.
Fields
source: ArrowErrorExisting Arrow failure.
Cleanup
Rewrite failed and one or more private objects could not be removed.
Fields
source: Box<EntityRewriteError>Primary rewrite failure.
cleanup_errors: Vec<StorageError>Typed cleanup failure for every private object that could not be removed.