#[non_exhaustive]pub enum TableError {
Create {
source: CreateTableError,
},
Open {
source: OpenTableError,
},
StateAccess {
source: TableStateAccessError,
},
Append {
source: AppendError,
},
Scan {
source: ScanError,
},
CoverageQuery {
source: CoverageQueryError,
},
Optimize {
source: OptimizeError,
},
}Expand description
Errors from high-level time-series table operations.
Each variant carries enough context for callers to surface actionable messages to users or implement retries where appropriate (for example, conflicts on optimistic concurrency control).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Create
A table creation operation failed.
Fields

source: CreateTableErrorComplete table creation failure.
Open
A table open operation failed.
Fields

source: OpenTableErrorComplete table open failure.
StateAccess
A table state access or refresh operation failed.
Fields

source: TableStateAccessErrorComplete state-access failure.
Append
An append operation failed.
Fields

source: AppendErrorComplete append-owned failure.
Scan
A table scan failed during planning or lazy execution.
CoverageQuery
A table coverage query failed.
Fields

source: CoverageQueryErrorComplete coverage query operation error.
Optimize
An entity-layout optimization operation failed.
Fields

source: OptimizeErrorComplete optimization-owned failure.